@@ -160,6 +160,33 @@ class Widget:
             s += f'{k}: {v};'
         return s
 
+    def as_webpage(self):
+        widget_deps = self.get_deps()
+        widget_soup = self.build()
+        tmpl = '''
+        <!DOCTYPE html>
+        <html lang="en">
+        <head>
+            <meta charset="UTF-8">
+            <meta name="viewport" content="width=device-width, initial-scale=1.0">
+            <meta http-equiv="X-UA-Compatible" content="ie=edge">
+        </head>
+        <body>
+        </body>
+        </html>
+        '''
+
+        soup = gen_soup(tmpl)
+        head = soup.find('head')
+        for dep_data in widget_deps:
+            dep_soup = dep_data['soup']
+            head.append(dep_soup)
+
+        body = soup.find('body')
+        body.append(widget_soup)
+
+        return soup.prettify()
+
     def build(self):
         cls = self.__class__
         cname = cls.__name__
